#!/bin/sh
#
# Copyright (c) 2015, Juniper Networks, Inc.
#

# Empty vars are mandatory, and must be passed in by the caller.
TARGET_DIR=
OBJDIR=bin

VERSION=
PLATFORMS="grantley ngsrx morpheus"
DOIT=echo
BUILD_TYPE=dev

# generic list
LIST="sb-sig-verify.sh\
	OsIndicate.sh\
	cert-to-efi-sig-list \
	efi-readvar \
	hash-to-efi-sig-list \
	KeyTool.efi \
	KeyTool-signed.efi \
	ReadVars.efi \
	ReadVars-signed.efi \
	sig-list-to-certs \
	sign-efi-sig-list \
	UpdateVars.efi \
	UpdateVars-signed.efi"

# platform specific list
for p in ${PLATFORMS}; do
	eval "LIST_${p}=\"efi-updatevar-${p}\""
done



Error() {
	echo "ERROR: $@" >&2
	exit 1
}

Mydir=`dirname $0`

while :
do
        case "$1" in
        *=*) eval "$1"; shift;;
        -d) DOIT= ; shift;;
        *) break;;
        esac
done


TARGET_DIR=${TARGET_DIR:-${Mydir}/publish}
VERSION=${VERSION:-`git rev-parse --short=10 HEAD`}

publish() {
	local subdir=$1
	local ver=$2
	local target=
	local _LIST

	echo "Publishing ${ver} to ${TARGET_DIR}/${subdir}, confirm [Y|N]?"
	read foo

	case $foo in
	*n*|*N*) Error cancelled ;;
	esac

	${DOIT} mkdir -p ${TARGET_DIR}/${subdir}/${ver} || Error mkdir

	eval "_LIST=\"${LIST} \$LIST_$subdir\""

	for item in ${_LIST}; do
		target=$item
		# strip out platform postfix if its there
		case $item in
		*-$subdir) target=${item%-*} ;;
		esac
		$DOIT cp ${item} ${TARGET_DIR}/${subdir}/${ver}/${target} || Error cp
	done

	${DOIT} rm -f ${TARGET_DIR}/${subdir}/current || Error rm

	(
		${DOIT} cd ${TARGET_DIR}/${subdir} || Error cd
		${DOIT} rm -f current || Error rm
		${DOIT} ln -s ${ver} current || error ln
	)
}

for p in ${PLATFORMS}; do
	publish $p ${VERSION}
done
